.. Slurmize documentation master file, created by
   sphinx-quickstart on Tue Feb  4 16:43:52 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

***********************
|project| documentation
***********************

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
